@@ -24,7 +24,7 @@
  # DAMAGES.
 
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 __author__ = 'Jeremy R. Gray'
 __contact__ = 'jrgray@gmail.com'
 
@@ -479,7 +479,7 @@ def hmac_sha256(key, filename):
     if not key:
         return None
     if getsize(filename) > MAX_FILE_SIZE:
-        _fatal('hmac_sha256: msg too large (> max file size)')
+        _fatal('hmac_sha256: file too large (> max file size)')
     cmd_HMAC = [OPENSSL, 'dgst', '-sha256', '-hmac', key, filename]
     hmac_openssl = _sys_call(cmd_HMAC)
 
@@ -531,7 +531,6 @@ def make_archive(paths, name='', keep=True):
             except OSError:
                 os.unlink(p)
     tar_fd.close()
-    os.chmod(name, PERMISSIONS)  # redundant, but not enough on win?
 
     return name
 
@@ -999,8 +998,8 @@ def _encrypt_rsa_aes256cbc(datafile, pub, OPENSSL=''):
     logging.debug('%s: start' % name)
 
     # Define file paths:
-    data_enc = _uniq_file(abspath(datafile) + AES_EXT)
-    pwd_rsa = _uniq_file(data_enc + RSA_EXT)
+    data_enc = _uniq_file(abspath(datafile + AES_EXT))
+    pwd_rsa = data_enc + RSA_EXT  # path to RSA-encrypted session key
 
     # Define command to RSA-PUBKEY-encrypt the pwd, save ciphertext to file:
     if use_rsautl:
@@ -1020,7 +1019,7 @@ def _encrypt_rsa_aes256cbc(datafile, pub, OPENSSL=''):
               '-out', data_enc,
               '-pass', 'stdin']
 
-    # Generate a password, ensure no whitespace (should never happen):
+    # Generate a password (digital envelope "session" key):
     pwd = _printable_pwd(nbits=256)
     assert not whitespace_re.search(pwd)
     try:
@@ -1223,7 +1222,8 @@ def _decrypt_rsa_aes256cbc(data_enc, pwd_rsa, priv, pphr=None,
               '-out', data_dec,
               '-pass', 'stdin']
 
-    # retrieve password (to RAM), then use to decrypt the data file:
+    # decrypt pwd (digital envelope "session" key) to RAM using private key
+    # then use pwd to decrypt the ciphertext file (data_enc):
     try:
         if pphr and not isfile(pphr):
             pwd, se_RSA = _sys_call(cmdRSA, stdin=pphr, stderr=True)  # want se
@@ -1238,9 +1238,10 @@ def _decrypt_rsa_aes256cbc(data_enc, pwd_rsa, priv, pphr=None,
     finally:
         if 'pwd' in locals():
             del pwd  # might as well try
-            # e.g., manual interrupt when queried for passphrase
 
-    se_RSA = se_RSA.replace("Loading 'screen' into random state - done", '')
+    if sys.platform == 'win32':
+        unhelpful_glop = "Loading 'screen' into random state - done"
+        se_RSA = se_RSA.replace(unhelpful_glop, '')
     if se_RSA.strip():
         if 'unable to load Private Key' in se_RSA:
             _fatal('%s: unable to load Private Key' % name, PrivateKeyError)
@@ -1366,16 +1367,16 @@ def verify(filename, pub, sig):
     """Verify signature of filename using pubkey; expects a base64-encoded sig.
     """
     name = 'verify'
-    logging.debug(name + ': start')
-    with NamedTemporaryFile() as sig_file:
+    logging.debug(name + ': start, file ' + filename)
+    if use_rsautl:
+        cmd_VERIFY = [OPENSSL, 'dgst', '-verify', pub, '-keyform', 'PEM']
+    else:
+        raise NotImplementedError
+
+    with NamedTemporaryFile(delete=False) as sig_file:
         sig_file.write(b64decode(sig))
-        sig_file.seek(0)
-        if use_rsautl:
-            cmd_VERIFY = [OPENSSL, 'dgst', '-verify', pub, '-keyform',
-                          'PEM', '-signature', sig_file.name, filename]
-        else:
-            raise NotImplementedError
-        result = _sys_call(cmd_VERIFY)
+    result = _sys_call(cmd_VERIFY + ['-signature', sig_file.name, filename])
+    os.unlink(sig_file.name)
 
     return result in ['Verification OK', 'Verified OK']
 
@@ -1927,6 +1928,10 @@ class Tests(object):
         assert pad2len * 1.02 < size_enc < pad2len * 1.20  # 1.093
 
     def test_permissions(self):
+        if sys.platform == 'win32':
+            pytest.skip()
+            # need different tests
+
         assert PERMISSIONS == 0o600
         assert UMASK == 0o077
 
@@ -1937,8 +1942,7 @@ class Tests(object):
             fd.write(b'\0')
         assert _get_file_permissions(filename) == 0o666  # permissive to test
         enc = encrypt(filename, pub)
-        # os.chmod(enc, PERMISSIONS)  # even this fails win32 as admin
-        assert _get_file_permissions(enc) == PERMISSIONS  # fails win32
+        assert _get_file_permissions(enc) == PERMISSIONS
         assert not os.path.isfile(filename)
         dec = decrypt(enc, priv, pphr)
         assert _get_file_permissions(dec) == PERMISSIONS  # restricted
